#pragma once
#include <panda/net/sockaddr.h>
#include <catch2/catch_test_macros.hpp>

using namespace panda;
using namespace panda::net;

SockAddr get_empty_sa();
